@@ -37,7 +37,7 @@ using Mono.Unix;
 using Hyena;
 using Hyena.Query;
 using Hyena.Data.Sqlite;
- 
+
 using Banshee.Base;
 using Banshee.Query;
 using Banshee.Sources;
@@ -55,7 +55,7 @@ namespace Banshee.SmartPlaylist
     {
         private static List<SmartPlaylistSource> playlists = new List<SmartPlaylistSource> ();
         private static uint timeout_id = 0;
-        
+
         static SmartPlaylistSource () {
             Migrator.MigrateAll ();
 
@@ -65,13 +65,13 @@ namespace Banshee.SmartPlaylist
 
         private static string generic_name = Catalog.GetString ("Smart Playlist");
         private static string properties_label = Catalog.GetString ("Edit Smart Playlist");
-    
+
         private QueryOrder query_order;
         private QueryLimit limit;
         private IntegerQueryValue limit_value;
-        
+
         private List<SmartPlaylistSource> dependencies = new List<SmartPlaylistSource>();
-        
+
 
 #region Properties
 
@@ -116,7 +116,7 @@ namespace Banshee.SmartPlaylist
                 if (condition != null) {
                     condition_sql = condition.ToSql (BansheeQuery.FieldSet);
                     condition_xml = condition.ToXml (BansheeQuery.FieldSet);
-                    
+
                     foreach (QueryTermNode term in condition.GetTerms ()) {
                         if (!relevant_fields.Contains (term.Field))
                             relevant_fields.Add (term.Field);
@@ -176,12 +176,16 @@ namespace Banshee.SmartPlaylist
                 return (Limit != null && LimitValue != null && !LimitValue.IsEmpty && QueryOrder != null);
             }
         }
-        
+
         public override bool HasDependencies {
             get { return dependencies.Count > 0; }
         }
 
         // FIXME scan ConditionTree for date fields
+        // FIXME even better, scan for date fields and see how fine-grained they are;
+        //       eg if set to Last Added < 2 weeks ago, don't need a timer going off
+        //       every 1 minute - every hour or two would suffice.  Just change this
+        //       property to a TimeSpan, rename it TimeDependentResolution or something
         public bool TimeDependent {
             get { return false; }
         }
@@ -190,13 +194,13 @@ namespace Banshee.SmartPlaylist
 
 #region Constructors
 
-        public SmartPlaylistSource (string name, int primarySourceId) : base (generic_name, name, primarySourceId)
+        public SmartPlaylistSource (string name, PrimarySource parent) : base (generic_name, name, parent)
         {
             SetProperties ();
         }
 
-        public SmartPlaylistSource (string name, QueryNode condition, QueryOrder order, QueryLimit limit, IntegerQueryValue limit_value, int primarySourceId)
-            : this (name, primarySourceId)
+        public SmartPlaylistSource (string name, QueryNode condition, QueryOrder order, QueryLimit limit, IntegerQueryValue limit_value, PrimarySource parent)
+            : this (name, parent)
         {
             ConditionTree = condition;
             QueryOrder = order;
@@ -208,8 +212,8 @@ namespace Banshee.SmartPlaylist
         }
 
         // For existing smart playlists that we're loading from the database
-        protected SmartPlaylistSource (int dbid, string name, string condition_xml, string order_by, string limit_number, string limit_criterion, int primarySourceId, int count, bool is_temp) :
-            base (generic_name, name, dbid, -1, 0, primarySourceId, is_temp)
+        protected SmartPlaylistSource (int dbid, string name, string condition_xml, string order_by, string limit_number, string limit_criterion, PrimarySource parent, int count, bool is_temp) :
+            base (generic_name, name, dbid, -1, 0, parent, is_temp)
         {
             ConditionXml = condition_xml;
             QueryOrder = BansheeQuery.FindOrder (order_by);
@@ -244,17 +248,17 @@ namespace Banshee.SmartPlaylist
         }
 
 #endregion
-        
+
 #region Private Methods
-        
+
         private void UpdateDependencies ()
         {
             foreach (SmartPlaylistSource s in dependencies) {
                 s.Updated -= OnDependencyUpdated;
             }
-            
+
             dependencies.Clear ();
-            
+
             if (ConditionTree != null) {
                 foreach (SmartPlaylistQueryValue value in ConditionTree.SearchForValues<SmartPlaylistQueryValue> ()) {
                     SmartPlaylistSource playlist = value.ObjectValue;
@@ -265,12 +269,12 @@ namespace Banshee.SmartPlaylist
                 }
             }
         }
-        
+
         private void OnDependencyUpdated (object sender, EventArgs args)
         {
             Reload ();
         }
-        
+
 #endregion
 
 #region AbstractPlaylist overrides
@@ -357,10 +361,11 @@ namespace Banshee.SmartPlaylist
 
         public void Refresh ()
         {
-            // Wipe the member list clean and repopulate it 
+            // Wipe the member list clean and repopulate it
             string reload_str = String.Format (
                 @"DELETE FROM CoreSmartPlaylistEntries WHERE SmartPlaylistID = {0};
-                  INSERT INTO CoreSmartPlaylistEntries 
+                  INSERT INTO CoreSmartPlaylistEntries
+                    (EntryID, SmartPlaylistID, TrackID)
                     SELECT NULL, {0} as SmartPlaylistID, TrackId FROM {1}
                         WHERE {2} AND CoreTracks.PrimarySourceID = {3}
                         {4} {5} {6}",
@@ -373,7 +378,7 @@ namespace Banshee.SmartPlaylist
             if (IsLimited && !Limit.RowBased) {
                 // Identify where the cut off mark is
                 HyenaSqliteCommand limit_command = new HyenaSqliteCommand (String.Format (
-                    @"SELECT EntryID, {0} 
+                    @"SELECT EntryID, {0}
                       FROM CoreTracks, CoreSmartPlaylistEntries
                       WHERE SmartPlaylistID = {1} AND CoreSmartPlaylistEntries.TrackID = CoreTracks.TrackID
                       ORDER BY EntryID",
@@ -482,12 +487,12 @@ namespace Banshee.SmartPlaylist
             return sql;
         }
 
-        public static IEnumerable<SmartPlaylistSource> LoadAll (int primary_id)
+        public static IEnumerable<SmartPlaylistSource> LoadAll (PrimarySource parent)
         {
             ClearTemporary ();
             using (HyenaDataReader reader = new HyenaDataReader (ServiceManager.DbConnection.Query (
                 @"SELECT SmartPlaylistID, Name, Condition, OrderBy, LimitNumber, LimitCriterion, PrimarySourceID, CachedCount, IsTemporary
-                    FROM CoreSmartPlaylists WHERE PrimarySourceID = ?", primary_id))) {
+                    FROM CoreSmartPlaylists WHERE PrimarySourceID = ?", parent.DbId))) {
                 while (reader.Read ()) {
                     SmartPlaylistSource playlist = null;
                     try {
@@ -495,12 +500,12 @@ namespace Banshee.SmartPlaylist
                             reader.Get<int> (0), reader.Get<string> (1),
                             reader.Get<string> (2), reader.Get<string> (3),
                             reader.Get<string> (4), reader.Get<string> (5),
-                            reader.Get<int> (6), reader.Get<int> (7), reader.Get<bool> (8)
+                            parent, reader.Get<int> (7), reader.Get<bool> (8)
                         );
                     } catch (Exception e) {
                         Log.Warning ("Ignoring Smart Playlist", String.Format ("Caught error: {0}", e), false);
                     }
-                    
+
                     if (playlist != null) {
                         yield return playlist;
                     }
